<!--
  ninjobon.xsl, ver.0.1
  written by Toshinobu OGISO & Yuho KITAZAKI
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:template match="/">
    <html>
      <head>
        <meta http-equiv="X-UA-Compatible" content="IE=edge"/>
        <meta http-equiv="Content-Style-Type" content="text/css" />
        <style>
          body{background:ivory;overflow-x: scroll;overflow-y:auto;writing-mode:tb-rl}
          .text_title{font-size:16pt;font-weight:bold;line-height:3;}
          .honmon{font-size:14pt;font-family:'ＭＳ 明朝',serif;line-height:2.6;}
          .article{border:thin solid gray;margin:1em;padding:1em;}
          .article_title{color:white;font-family:'ＭＳ Ｐゴシック',sans-serif;font-size:14pt;font-weight:bold;line-height:2;background-color:royalblue;margin:0.5em 0em;padding:0.5em 1em;}
          .target_string{color:magenta;font-weight:bold;}
          .figureBlock{padding:1.5em 0em 1.5em 1em;}
          .figureBlock span{color:grey;font-size:11pt;font-family:'ＭＳ Ｐゴシック',sans-serif;font-weight:bold;border:medium solid gray;padding:2em 5em;}
          .s{color:gold;font-weight:bold;}
          .warigaki{font-size:11pt;}
          .kogaki{font-size:10pt;vertical-align:super;}
          .kakomi{font-size:11pt;border:thin solid;margin:0.1em;padding:0.1em;}
          .pb{font-size:10pt;font-weight:bold;color:gray;text-decoration:none}
          .gap{border:thin solid gray;background-color:gray;cursor:pointer;}
          .r{font-size:8pt;vertical-align:super;}
          .lr{font-size:8pt;vertical-align:sub;}
          q.speech{color:black;background-color:AntiqueWhite;margin:0.2em;padding:0.3em;cursor:pointer;quotes:"" "";}
          q.suw{color:black;cursor:pointer;quotes:"" "";}
          
          .chu{font-size:10pt;color:red;vertical-align:super;cursor:pointer;}
          .modified{color:red;cursor:pointer;}
          .yoko{writing-mode:lr-tb}
        </style>
        <title>
            <xsl:value-of select="text/@title"/>〈<xsl:value-of select="text/@year_w"/>（<xsl:value-of select="text/@year"/>）年〉
        </title>
      </head>
      <body>
          <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="text">
        <div class="honmon">
          <div class="text_title">
            <xsl:value-of select="@title"/>　<span class="yoko"><xsl:value-of select="@year_w"/></span><span class="yoko">（<xsl:value-of select="@year"/>）</span>年　<xsl:value-of select="@place"/>
          </div>
          <xsl:apply-templates/>
        </div>
 </xsl:template>

  <xsl:template match="front|back">
  <hr/>
       <xsl:apply-templates/>
  <hr/>
  </xsl:template>  
  
  <xsl:template match="titleBlock">
    <div class="article">
      <span class="text_title"><xsl:apply-templates/></span>
    </div>
  </xsl:template>
  
  <xsl:template match="article">
    <div class="article">
      <xsl:apply-templates/>
    </div>
  </xsl:template>
  
  <xsl:template match="tg">
    <a class="target_string">
      <xsl:attribute name="id">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
        <xsl:apply-templates/>
    </a>
  </xsl:template>

  <xsl:template match="p|block">
    <xsl:apply-templates/><br/>
  </xsl:template>
  
  <xsl:template match="figureBlock">
    <div class="figureBlock">
      <span>図表</span>
    </div>
    <xsl:apply-templates/>
  </xsl:template>  
  
  <xsl:template match="warigaki">
    <span class="warigaki">
      <xsl:apply-templates/>
    </span>
  </xsl:template>

  <xsl:template match="speech">
     <q class="speech" title="話者={@source}"><xsl:apply-templates/></q>
  </xsl:template>


  <xsl:template match="hi">
  <xsl:choose>
      <xsl:when test="@rend='囲み'">
	    <span class="kakomi"><xsl:apply-templates/></span>
      </xsl:when>
      <xsl:when test="@rend='小書き'">
	    <span class="kogaki"><xsl:apply-templates/></span>
      </xsl:when>
            <xsl:otherwise>
            <xsl:apply-templates/>
            </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  
  <xsl:template match="s">
    <xsl:apply-templates/><span class="s">|</span>
  </xsl:template>

  <xsl:template match="odoriji">
    <span class="modified" title="踊字 原文={@originalText}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="gap">
    <xsl:apply-templates/><span class="gap" title="判読不可">　</span>
  </xsl:template>

  <xsl:template match="missing">
    <span class="gap" title="{@agent}"><xsl:apply-templates/></span>
  </xsl:template>

  <xsl:template match="pb">
      	<span class="pb">〔<xsl:value-of select="@n"/>〕</span>
  </xsl:template>
  
  <xsl:template match="SUW">
  <q class="suw" title="短単位 語彙素={@lemma} 品詞={@pos} 活用形={@cForm} 仮名形={@kanaToken}">
    <xsl:apply-templates/>
  </q>
  </xsl:template>
  
  <xsl:template match="r">
    <ruby>
    <rb><xsl:apply-templates/></rb>
    <rp>(</rp><rt><xsl:value-of select="@rt"/></rt><rp>)</rp>
    </ruby>
  </xsl:template>

  <xsl:template match="lRuby">
    <xsl:apply-templates/>
    <span class="lr">
      <xsl:value-of select="@rubyText"/>
    </span>
  </xsl:template>
  
  <xsl:template match="corr">
    <xsl:choose>
      <xsl:when test="@subType='ruby'">
        <xsl:apply-templates/><span class="chu" title="{@type} ルビ原文={@originalText}">※</span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:if test="@type='erratum'">
          <xsl:apply-templates/><span class="chu" title="誤字 原文={@originalText}">※</span>         
        </xsl:if>
        <xsl:if test="@type='excess'">
          <xsl:apply-templates/><span class="chu" title="衍字 原文={@originalText}">※</span>         
        </xsl:if>
        <xsl:if test="@type='omission'">
          <xsl:apply-templates/><span class="chu" title="脱字">※</span>         
        </xsl:if>
        <xsl:if test="@type='revision'">
          <xsl:apply-templates/><span class="chu" title="校訂元={@source}">※</span>         
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="unclear">
          <xsl:apply-templates/><span class="chu" title="不鮮明">※</span>
  </xsl:template>

  <xsl:template match="vMark">
    <xsl:choose>
      <xsl:when test="@type='ruby'">
        <xsl:apply-templates/><span class="modified" title="濁点無表記 ルビ原文={@originalText}">※</span>
      </xsl:when>
      <xsl:otherwise>
        <span class="modified" title="濁点無表記"><xsl:apply-templates/></span>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="corrSpan">
        <span class="modified" title="タイプ={@type} 原文={@originalText}"><xsl:apply-templates/></span>
  </xsl:template>


  <xsl:template match="span">
      <xsl:choose>
      <xsl:when test="@script='カタカナ'">
        <span class="modified" title="原文カタカナ"><xsl:apply-templates/></span>
        </xsl:when>
      <xsl:otherwise>
        <span class="modified"><xsl:apply-templates/></span>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template match="char">
      <xsl:choose>
      <xsl:when test="@script='カタカナ'">
        <span class="modified" title="原文カタカナ"><xsl:apply-templates/></span>
        </xsl:when>
      <xsl:otherwise>
        <span class="modified"><xsl:apply-templates/></span>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="g">
    <xsl:choose>
      <xsl:when test="@type='外字'">
        <xsl:apply-templates/><span class="chu" title="{@type} 字形説明={@ref}">※</span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/><span class="chu" title="{@type}">※</span>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="kanbun">
    <xsl:if test="@type='返読前'">
      <xsl:apply-templates/><span class="chu" title="{@type} 原文={@originalText} ID={@id}">※</span>
    </xsl:if>
    <xsl:if test="@type='返読後'">
      <xsl:apply-templates/><span class="chu" title="{@type} ID={@id}">※</span>
    </xsl:if>
    <xsl:if test="@type='補読'">
      <xsl:apply-templates/><span class="chu" title="{@type}">※</span>
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>